# Generated by Django 4.2.23 on 2025-10-19 18:22

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0034_blueprintcopyoffer_accepted_by_seller"),
    ]

    operations = [
        migrations.AlterField(
            model_name="blueprintcopychat",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="blueprintcopymessage",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
