# Generated by Django 4.2.23 on 2025-10-20 20:11

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0037_corporationsharingsetting_authorized_characters"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="charactersettings",
            options={
                "default_permissions": (),
                "verbose_name": "Character setting",
                "verbose_name_plural": "Character settings",
            },
        ),
    ]
