# Generated by Django 4.2.21 on 2025-06-08 23:01

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("indy_hub", "0011_alter_blueprintcopyoffer_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="industryjob",
            name="job_completed_notified",
            field=models.BooleanField(default=False),
        ),
    ]
